@@ -42,9 +42,10 @@ Python package releaser
 Options:
   -C, --no-commit       Do not commit modified files from the sandbox.
   -T, --no-tag          Do not tag the release in SCM.
+  -P, --no-push         Do not push commits and tags upstream.
   -R, --no-register     Do not register the release with dist-location.
   -S, --no-upload       Do not upload the release to dist-location.
-  -n, --dry-run         Dry-run; equivalent to -CTRS.
+  -n, --dry-run         Dry-run; equivalent to -CTPRS.
 
   --svn, --hg, --git    Select the SCM type. Only required if the SCM type
                         cannot be guessed from the argument.
@@ -58,12 +59,11 @@ Options:
   -i identity, --identity=identity
                         The GnuPG identity to sign with. Implies -s.
 
-  -z, --zip             Release a zip archive (default).
-  -g, --gztar           Release a tar.gz archive.
-  -b, --binary          Release a binary egg.
-  -w, --wheel           Release a wheel file.
+  -z, --zip             Release a zip archive.
+  -g, --gztar           Release a tar.gz archive (default).
+  -b, --egg             Release a binary egg.
+  -w, --wheel           Release a wheel file (default).
 
-  -p, --push            Push sandbox modifications upstream.
   -m, --manifest-only   Ignore setuptools extensions and collect files via
                         MANIFEST.in only.
   -e, --develop         Allow setuptools build tags. Implies -T.
@@ -80,6 +80,8 @@ Options:
   -v, --version         Print the version string and exit.
 
   --no-color            Disable output colors.
+  --non-interactive     Do not prompt for username and password if the
+                        required credentials are missing.
 
 Arguments:
   scm-sandbox           A local SCM sandbox. Defaults to the current working
@@ -109,16 +111,17 @@ class Defaults(object):
 
         self.commit = parser.getboolean(main_section, 'commit', True)
         self.tag = parser.getboolean(main_section, 'tag', True)
-        self.register = parser.getboolean(main_section, 'register', True)
+        self.register = parser.getboolean(main_section, 'register', False)
         self.upload = parser.getboolean(main_section, 'upload', True)
         self.formats = parser.getlist(main_section, 'formats', [])
         self.sign = parser.getboolean(main_section, 'sign', False)
         self.identity = parser.getstring(main_section, 'identity', '')
-        self.push = parser.getboolean(main_section, 'push', False)
+        self.push = parser.getboolean(main_section, 'push', True)
         self.manifest = parser.getboolean(main_section, 'manifest-only', False)
         self.develop = parser.getboolean(main_section, 'develop', False)
         self.quiet = parser.getboolean(main_section, 'quiet', False)
         self.twine = parser.getstring(main_section, 'twine', '')
+        self.interactive = parser.getboolean(main_section, 'interactive', True)
 
         for format in self.formats:
             if format not in ('zip', 'gztar', 'egg', 'wheel'):
@@ -270,11 +273,11 @@ class ReleaseMaker(object):
         """Set defaults.
         """
         self.defaults = Defaults(config_file)
-        self.locations = Locations(self.defaults)
+        self.locations = Locations(defaults=self.defaults)
         self.python = Python()
         self.setuptools = Setuptools()
         self.twine = Twine(defaults=self.defaults)
-        self.scp = SCP()
+        self.scp = SCP(defaults=self.defaults)
         self.scms = SCMFactory()
         self.urlparser = URLParser()
         self.skipcommit = not self.defaults.commit
@@ -317,7 +320,8 @@ class ReleaseMaker(object):
                  'sign', 'identity=', 'dist-location=', 'version', 'help',
                  'push', 'quiet', 'svn', 'hg', 'git', 'develop', 'binary',
                  'list-locations', 'config-file=', 'wheel', 'zip', 'gztar',
-                 'manifest-only', 'trace', 'egg', 'no-push', 'twine=', 'no-color'))
+                 'manifest-only', 'trace', 'egg', 'no-push', 'twine=',
+                 'no-color', 'non-interactive'))
         except getopt.GetoptError as e:
             err_exit('mkrelease: %s\n%s' % (e.msg.capitalize(), USAGE))
 
@@ -332,9 +336,9 @@ class ReleaseMaker(object):
                 self.skipupload = True
             elif name in ('-n', '--dry-run'):
                 self.skipcommit = self.skiptag = self.skipregister = self.skipupload = True
-            elif name in ('-p', '--push'):
+            elif name in ('-p', '--push'):      # undocumented
                 self.push = True
-            elif name in ('-P', '--no-push'):   # undocumented
+            elif name in ('-P', '--no-push'):
                 self.push = False
             elif name in ('-q', '--quiet'):
                 self.quiet = True
@@ -369,7 +373,10 @@ class ReleaseMaker(object):
             elif name in ('--no-color',):
                 os.environ['JARN_NO_COLOR'] = '1'
             elif name in ('-t', '--twine'):
-                self.twine = Twine(twine=value)
+                self.twine.twine = expanduser(value)
+            elif name in ('--non-interactive',):
+                self.twine.interactive = False
+                self.scp.interactive = False
             elif name in ('-c', '--config-file') and depth == 0:
                 self.reset_defaults(expanduser(value))
                 return self.parse_options(args, depth+1)
@@ -473,7 +480,8 @@ class ReleaseMaker(object):
                 self.distributions.append(('bdist_wheel', []))
 
         if not self.distributions:
-            self.distributions.append(('sdist', ['--formats="zip"']))
+            self.distributions.append(('sdist', ['--formats="gztar"']))
+            self.distributions.append(('bdist_wheel', []))
 
         if self.list:
             self.list_locations()
