@@ -23,6 +23,11 @@ from .colors import bold
 OK_RESPONSE = 'Server response (200): OK'
 GONE_RESPONSE = 'Server response (410):'
 
+FILTERWARNINGS = ('-W "ignore:setup.py install is deprecated" '
+                  '-W "ignore:easy_install command is deprecated" '
+                  '-W "ignore:Support for \`[tool.setuptools]\` in \`pyproject.toml\`" '
+                  '-W "ignore:The namespace_packages parameter is deprecated"')
+
 
 class Setuptools(object):
     """Interface to setuptools."""
@@ -47,11 +52,14 @@ class Setuptools(object):
         return env
 
     def is_valid_package(self, dir):
-        return isfile(join(dir, 'setup.py')) or isfile(join(dir, 'setup.cfg'))
+        return (isfile(join(dir, 'setup.py')) or
+                isfile(join(dir, 'setup.cfg')) or
+                isfile(join(dir, 'pyproject.toml')))
 
     def check_valid_package(self, dir):
         if not self.is_valid_package(dir):
-            err_exit('mkrelease: No setup.py in %(dir)s' % locals())
+            err_exit('mkrelease: No setup in %(dir)s\n'
+                     'Expected setup.py and/or setup.cfg and/or pyproject.toml' % locals())
 
     @chdir
     def get_package_info(self, dir, develop=False):
@@ -202,9 +210,9 @@ class Setuptools(object):
         setup.py.
         """
         python = self.python
-        run_setup = 'from jarn.mkrelease import setup; setup.run(%(args)r, ff=%(ff)r)'
-        filterwarnings = '-W "ignore:setup.py install is deprecated"'
+        filterwarnings = FILTERWARNINGS
 
+        run_setup = 'from jarn.mkrelease import setup; setup.run(%(args)r, ff=%(ff)r)'
         setup_py = '-c"%s"' % (run_setup % locals())
 
         rc, lines = self.process.popen(
